@@ -17,7 +17,7 @@ from .types import (
     SearchResult,
     StreamResponse,
     LogLevel,
-    ThinkAIError
+    ThinkAIError,
 )
 
 __version__ = "1.0.0"
@@ -27,16 +27,16 @@ __license__ = "MIT"
 
 __all__ = [
     "ThinkAI",
-    "create_client", 
+    "create_client",
     "quick_chat",
     "ThinkAIConfig",
     "ChatRequest",
-    "ChatResponse", 
+    "ChatResponse",
     "SystemStats",
     "HealthStatus",
     "KnowledgeDomain",
     "SearchResult",
     "StreamResponse",
     "LogLevel",
-    "ThinkAIError"
-]
\ No newline at end of file
+    "ThinkAIError",
+]
